@@ -7,9 +7,10 @@
 
     jl = JLStruct(;
         name=Symbol("typeof($(info.def.head.name))"),
-        fields=[JLField(; name=:data, type=:(Union{$(union_params...)}))],
+        fields=[JLField(; name=:data, type=:(Union{$(union_params...)}), isconst = info.def.ismutable)],
         typevars=info.whereparams,
-	supertype=isnothing(info.def.head.supertype) ? nothing : guess_self_as_any(info.def, info.def.head.supertype), 
+	supertype=isnothing(info.def.head.supertype) ? nothing : guess_self_as_any(info.def, info.def.head.supertype),
+	    ismutable = info.def.ismutable,
     )
 
     binding = if isempty(info.params)
